#
# Copyright 2024 by Delphix
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#    http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#

#
# This class has been automatically generated from:
#     /delphix-appdata-enable-parameters.json
#
# Do not edit this file manually!
#

from delphixpy.web.objects.SourceEnableParameters import SourceEnableParameters
from delphixpy import common

class __Undef:
    def __repr__(self):
        return "undef"

    def __setattr__(self, name, value):
        raise Exception('Cannot modify attributes of __Undef.')

_UNDEFINED = __Undef()

class AppDataEnableParameters(SourceEnableParameters):
    """
    *(extends* :py:class:`delphixpy.web.vo.SourceEnableParameters` *)* The
    parameters to use as input to enable AppData sources.
    """
    def __init__(self, undef_enabled=True):
        super().__init__()
        self._type = ("AppDataEnableParameters", True)
        self._container_mode = (self.__undef__, True)
        self._ownership_spec = (self.__undef__, True)


    @classmethod
    def from_dict(cls, data, dirty=False, undef_enabled=True):
        obj = super().from_dict(data, dirty, undef_enabled)
        obj._container_mode = (data.get("containerMode", obj.__undef__), dirty)
        if obj._container_mode[0] is not None and obj._container_mode[0] is not obj.__undef__:
            assert isinstance(obj._container_mode[0], bool), ("Expected one of ['boolean'], but got %s of type %s" % (obj._container_mode[0], type(obj._container_mode[0])))
            common.validate_format(obj._container_mode[0], "None", None, None)
        obj._ownership_spec = (data.get("ownershipSpec", obj.__undef__), dirty)
        if obj._ownership_spec[0] is not None and obj._ownership_spec[0] is not obj.__undef__:
            assert isinstance(obj._ownership_spec[0], str), ("Expected one of ['string'], but got %s of type %s" % (obj._ownership_spec[0], type(obj._ownership_spec[0])))
            common.validate_format(obj._ownership_spec[0], "None", None, 1024)
        return obj

    def to_dict(self, dirty=False, belongs_to_parent=False):
        dct = super().to_dict(dirty, belongs_to_parent)

        def dictify(obj, prop_is_list_or_vo=False):
            if isinstance(obj, list):
                return [dictify(o, prop_is_list_or_vo) for o in obj]
            elif hasattr(obj, "to_dict"):
                return obj.to_dict(dirty=dirty, belongs_to_parent=prop_is_list_or_vo)
            else:
                return obj
        if "container_mode" == "type" or (self.container_mode is not self.__undef__ and (not (dirty and not self._container_mode[1]))):
            dct["containerMode"] = dictify(self.container_mode)
        if "ownership_spec" == "type" or (self.ownership_spec is not self.__undef__ and (not (dirty and not self._ownership_spec[1]) or self.is_dirty_list(self.ownership_spec, self._ownership_spec) or belongs_to_parent)):
            dct["ownershipSpec"] = dictify(self.ownership_spec)
        return dct

    def dirty(self):
        return self.from_dict(self.to_dict(dirty=False), dirty=True)

    def force_dirty(self):
        self._container_mode = (self._container_mode[0], True)
        self._ownership_spec = (self._ownership_spec[0], True)

    def is_dirty(self):
        return any([self._container_mode[1], self._ownership_spec[1]])

    def is_dirty_list(self, prop_name, private_var):
        if isinstance(prop_name, list) and prop_name and hasattr(prop_name[0], 'type'):
            for item in prop_name:
                if isinstance(item, list):
                    if self.is_dirty_list(item) or item.is_dirty():
                        return True
                elif item.is_dirty():
                    return True
        else:
            return private_var[1]
        return False

    def __eq__(self, other):
        if other is None:
            return False
        if not isinstance(other, AppDataEnableParameters):
            return False
        return super().__eq__(other) and \
               self.container_mode == other.container_mode and \
               self.ownership_spec == other.ownership_spec

    def __ne__(self, other):
        return not self.__eq__(other)

    def __hash__(self):
        return id(self)

    def __repr__(self):
        return common.generate_repr_string(self)

    @property
    def container_mode(self):
        """
        Whether the database is running inside a container. This is currently
        applicable to virtual databases only.

        :rtype: ``bool``
        """
        return self._container_mode[0]

    @container_mode.setter
    def container_mode(self, value):
        self._container_mode = (value, True)

    @property
    def ownership_spec(self):
        """
        The uid:gid string that NFS mounts should belong to.

        :rtype: ``str``
        """
        return self._ownership_spec[0]

    @ownership_spec.setter
    def ownership_spec(self, value):
        self._ownership_spec = (value, True)

